@@ -180,7 +180,26 @@ gpm_manager_is_inhibit_valid (GpmManager *manager,
 		GString *message = g_string_new ("");
 		const char *msg;
 
-		title = g_strdup_printf (_("Request to %s"), action);
+		/*Compose message for each possible action*/
+		if (strcmp (action, "suspend") == 0) {
+				title = g_strdup_printf (_("Request to suspend")); 
+
+		} else if (strcmp (action, "hibernate") == 0) {
+				title = g_strdup_printf (_("Request to hibernate")); 
+
+		} else if (strcmp (action, "policy action") == 0) {
+				title = g_strdup_printf (_("Request to do policy action")); 
+
+		} else if (strcmp (action, "reboot") == 0) {
+				title = g_strdup_printf (_("Request to reboot")); 
+
+		} else if (strcmp (action, "shutdown") == 0) {
+				title = g_strdup_printf (_("Request to shutdown")); 
+
+		} else if (strcmp (action, "timeout action") == 0) {
+				title = g_strdup_printf (_("Request to do timeout action"));
+		}
+		
 		gpm_inhibit_get_message (manager->priv->inhibit, message, action);
 		gpm_notify_display (manager->priv->notify,
 				      title,
@@ -304,6 +323,7 @@ static gboolean
 gpm_manager_action_suspend (GpmManager *manager, const gchar *reason)
 {
 	gboolean allowed;
+	GError *error = NULL;
 
 	if (gpm_control_is_policy_timout_valid (manager->priv->control) == FALSE) {
 		/* error msg timeout not valid */
@@ -342,9 +362,17 @@ gpm_manager_action_suspend (GpmManager *manager, const gchar *reason)
 		return FALSE;
 	}
 
+	/* check to see if we are inhibited */
+	if (gpm_manager_is_inhibit_valid (manager, FALSE, "suspend") == FALSE) {
+		return FALSE;
+	}
+
 	gpm_info_explain_reason (manager->priv->info, GPM_EVENT_SUSPEND,
-				_("Suspending computer"), reason);
-	gpm_control_suspend (manager->priv->control, NULL);
+				_("Suspending computer."), reason);
+	gpm_control_suspend (manager->priv->control, &error);
+	if (error != NULL) {
+		g_error_free (error);
+	}
 	return TRUE;
 }
 
@@ -355,6 +383,7 @@ static gboolean
 gpm_manager_action_hibernate (GpmManager *manager, const gchar *reason)
 {
 	gboolean allowed;
+	GError *error = NULL;
 
 	if (gpm_control_is_policy_timout_valid (manager->priv->control) == FALSE) {
 		/* error msg timeout not valid */
@@ -393,9 +422,17 @@ gpm_manager_action_hibernate (GpmManager *manager, const gchar *reason)
 		return FALSE;
 	}
 
+	/* check to see if we are inhibited */
+	if (gpm_manager_is_inhibit_valid (manager, FALSE, "hibernate") == FALSE) {
+		return FALSE;
+	}
+
 	gpm_info_explain_reason (manager->priv->info, GPM_EVENT_SUSPEND,
-				_("Hibernating computer"), reason);
-	gpm_control_hibernate (manager->priv->control, NULL);
+				_("Hibernating computer."), reason);
+	gpm_control_hibernate (manager->priv->control, &error);
+	if (error != NULL) {
+		g_error_free (error);
+	}
 	return TRUE;
 }
 
@@ -425,6 +462,11 @@ manager_policy_do (GpmManager  *manager,
 		return FALSE;
 	}
 
+	/* are we inhibited? */
+	if (gpm_manager_is_inhibit_valid (manager, FALSE, "policy action") == FALSE) {
+		return FALSE;
+	}
+
 	gpm_debug ("policy: %s", policy);
 	gpm_conf_get_string (manager->priv->conf, policy, &action);
 
@@ -434,7 +476,7 @@ manager_policy_do (GpmManager  *manager,
 
 	if (strcmp (action, ACTION_NOTHING) == 0) {
 		gpm_info_explain_reason (manager->priv->info, GPM_EVENT_NOTIFICATION,
-					_("Doing nothing"), reason);
+					_("Doing nothing."), reason);
 
 	} else if (strcmp (action, ACTION_SUSPEND) == 0) {
 		gpm_manager_action_suspend (manager, reason);
@@ -447,12 +489,12 @@ manager_policy_do (GpmManager  *manager,
 
 	} else if (strcmp (action, ACTION_SHUTDOWN) == 0) {
 		gpm_info_explain_reason (manager->priv->info, GPM_EVENT_NOTIFICATION,
-					_("Shutting down computer"), reason);
+					_("Shutting down computer."), reason);
 		gpm_control_shutdown (manager->priv->control, NULL);
 
 	} else if (strcmp (action, ACTION_INTERACTIVE) == 0) {
 		gpm_info_explain_reason (manager->priv->info, GPM_EVENT_NOTIFICATION,
-					_("GNOME interactive logout"), reason);
+					_("GNOME interactive logout."), reason);
 		gnome_client_request_save (gnome_master_client (),
 					   GNOME_SAVE_GLOBAL,
 					   TRUE, GNOME_INTERACT_ANY, FALSE, TRUE);
@@ -492,6 +534,11 @@ gpm_manager_suspend (GpmManager *manager,
 		return FALSE;
 	}
 
+	/* check to see if we are inhibited */
+	if (gpm_manager_is_inhibit_valid (manager, FALSE, "hibernate") == FALSE) {
+		return FALSE;
+	}
+
 	return gpm_control_suspend (manager->priv->control, error);
 }
 
@@ -523,6 +570,11 @@ gpm_manager_hibernate (GpmManager *manager,
 		return FALSE;
 	}
 
+	/* check to see if we are inhibited */
+	if (gpm_manager_is_inhibit_valid (manager, FALSE, "hibernate") == FALSE) {
+		return FALSE;
+	}
+
 	return gpm_control_hibernate (manager->priv->control, error);
 }
 
@@ -537,6 +589,12 @@ gpm_manager_reboot (GpmManager *manager,
 {
 	g_return_val_if_fail (manager != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_MANAGER (manager), FALSE);
+
+	/* check to see if we are inhibited */
+	if (gpm_manager_is_inhibit_valid (manager, FALSE, "reboot") == FALSE) {
+		return FALSE;
+	}
+
 	return gpm_control_reboot (manager->priv->control, error);
 }
 
@@ -551,6 +609,12 @@ gpm_manager_shutdown (GpmManager *manager,
 {
 	g_return_val_if_fail (manager != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_MANAGER (manager), FALSE);
+
+	/* check to see if we are inhibited */
+	if (gpm_manager_is_inhibit_valid (manager, FALSE, "shutdown") == FALSE) {
+		return FALSE;
+	}
+
 	return gpm_control_shutdown (manager->priv->control, error);
 }
 
@@ -702,6 +766,7 @@ idle_do_sleep (GpmManager *manager)
 	gboolean on_ac;
 	gchar *action = NULL;
 	gboolean ret;
+	GError *error = NULL;
 
 	/* find if we are on AC power */
 	on_ac = gpm_ac_adapter_is_present (manager->priv->ac_adapter);
@@ -722,25 +787,31 @@ idle_do_sleep (GpmManager *manager)
 
 	} else if (strcmp (action, ACTION_SUSPEND) == 0) {
 		gpm_info_explain_reason (manager->priv->info, GPM_EVENT_SUSPEND,
-					_("Suspending computer"), _("System idle"));
-		ret = gpm_control_suspend (manager->priv->control, NULL);
+					_("Suspending computer."), _("System idle."));
+		ret = gpm_control_suspend (manager->priv->control, &error);
 		if (ret == FALSE) {
-			gpm_warning ("cannot suspend, so trying hibernate");
-			ret = gpm_control_hibernate (manager->priv->control, NULL);
+			gpm_warning ("cannot suspend (error: %s), so trying hibernate", error->message);
+			g_error_free (error);
+			error = NULL;
+			ret = gpm_control_hibernate (manager->priv->control, &error);
 			if (ret == FALSE) {
-				gpm_warning ("cannot suspend or hibernate!");
+				gpm_warning ("cannot suspend or hibernate: %s", error->message);
+				g_error_free (error);
 			}
 		}
 
 	} else if (strcmp (action, ACTION_HIBERNATE) == 0) {
 		gpm_info_explain_reason (manager->priv->info, GPM_EVENT_HIBERNATE,
-					_("Hibernating computer"), _("System idle"));
-		ret = gpm_control_hibernate (manager->priv->control, NULL);
+					_("Hibernating computer."), _("System idle."));
+		ret = gpm_control_hibernate (manager->priv->control, &error);
 		if (ret == FALSE) {
-			gpm_warning ("cannot hibernate, so trying suspend");
-			ret = gpm_control_suspend (manager->priv->control, NULL);
+			gpm_warning ("cannot hibernate (error: %s), so trying suspend", error->message);
+			g_error_free (error);
+			error = NULL;
+			ret = gpm_control_suspend (manager->priv->control, &error);
 			if (ret == FALSE) {
-				gpm_warning ("cannot suspend or hibernate!");
+				gpm_warning ("cannot suspend or hibernate: %s", error->message);
+				g_error_free (error);
 			}
 		}
 	}
@@ -787,7 +858,7 @@ idle_changed_cb (GpmIdle    *idle,
 		if (gpm_control_is_policy_timout_valid (manager->priv->control) == FALSE) {
 			return;
 		}
-		if (! gpm_manager_is_inhibit_valid (manager, FALSE, "timeout action")) {
+		if (gpm_manager_is_inhibit_valid (manager, FALSE, "timeout action") == FALSE) {
 			return;
 		}
 		idle_do_sleep (manager);
@@ -825,7 +896,7 @@ battery_button_pressed (GpmManager *manager)
 static void
 power_button_pressed (GpmManager *manager)
 {
-	manager_policy_do (manager, GPM_CONF_BUTTON_POWER, _("the power button has been pressed"));
+	manager_policy_do (manager, GPM_CONF_BUTTON_POWER, _("The power button has been pressed."));
 }
 
 /**
@@ -837,7 +908,7 @@ power_button_pressed (GpmManager *manager)
 static void
 suspend_button_pressed (GpmManager *manager)
 {
-	manager_policy_do (manager, GPM_CONF_BUTTON_SUSPEND, _("the suspend button has been pressed"));
+	manager_policy_do (manager, GPM_CONF_BUTTON_SUSPEND, _("The suspend button has been pressed."));
 }
 
 /**
@@ -849,7 +920,7 @@ suspend_button_pressed (GpmManager *manager)
 static void
 hibernate_button_pressed (GpmManager *manager)
 {
-	manager_policy_do (manager, GPM_CONF_BUTTON_HIBERNATE, _("the hibernate button has been pressed"));
+	manager_policy_do (manager, GPM_CONF_BUTTON_HIBERNATE, _("The hibernate button has been pressed."));
 }
 
 /**
@@ -880,7 +951,7 @@ lid_button_pressed (GpmManager *manager,
 	if (on_ac == TRUE) {
 		gpm_debug ("Performing AC policy");
 		manager_policy_do (manager, GPM_CONF_BUTTON_LID_AC,
-				   _("the lid has been closed on ac power"));
+				   _("The lid has been closed on ac power."));
 		return;
 	}
 
@@ -910,7 +981,7 @@ lid_button_pressed (GpmManager *manager,
 
 	gpm_debug ("Performing battery policy");
 	manager_policy_do (manager, GPM_CONF_BUTTON_LID_BATT,
-			   _("the lid has been closed on battery power"));
+			   _("The lid has been closed on battery power."));
 }
 
 /**
@@ -999,8 +1070,8 @@ ac_adapter_changed_cb (GpmAcAdapter *ac_adapter,
 	    on_ac == FALSE &&
 	    gpm_button_is_lid_closed (manager->priv->button)) {
 		manager_policy_do (manager, GPM_CONF_BUTTON_LID_BATT,
-				   _("the lid has been closed, and the ac adapter "
-				     "removed (and gconf is okay)"));
+				   _("The lid has been closed, and the ac adapter "
+				     "removed (and gconf is okay)."));
 	}
 
 	/* Don't do any events for a few seconds after we remove the
@@ -1022,7 +1093,7 @@ manager_critical_action_do (GpmManager *manager)
 {
 	manager_policy_do (manager,
 			   GPM_CONF_ACTIONS_CRITICAL_BATT,
-			   _("battery is critically low"));
+			   _("Battery is critically low."));
 	return FALSE;
 }
 
@@ -1112,7 +1183,7 @@ static void
 gpm_manager_tray_icon_hibernate (GpmManager  *manager,
 				 GpmTrayIcon *tray)
 {
-	gpm_manager_action_hibernate (manager, "clicked tray");
+	gpm_manager_action_hibernate (manager, _("User clicked on tray"));
 }
 
 /**
@@ -1127,7 +1198,7 @@ static void
 gpm_manager_tray_icon_suspend (GpmManager   *manager,
 			       GpmTrayIcon  *tray)
 {
-	gpm_manager_action_suspend (manager, "clicked tray");
+	gpm_manager_action_suspend (manager, _("User clicked on tray"));
 }
 
 /**
